@@ -599,7 +599,7 @@ async def cli(session, api_client, **params):
         [get_aax, get_aaxc, get_annotation, get_chapters, get_cover, get_pdf]
     ):
         logger.error("Please select an option what you want download.")
-        click.Abort()
+        raise click.Abort()
 
     # additional options
     sim_jobs = params.get("jobs")
@@ -621,7 +621,11 @@ async def cli(session, api_client, **params):
     library = await Library.from_api_full_sync(
         api_client,
         image_sizes="1215, 408, 360, 882, 315, 570, 252, 558, 900, 500",
-        bunch_size=bunch_size
+        bunch_size=bunch_size,
+        response_groups=(
+            "product_desc, media, product_attrs, relationships, "
+            "series, customer_rights"
+        )
     )
 
     if resolve_podcats:
