@@ -61,7 +61,7 @@ class BaseItem:
     @property
     def full_title_slugify(self):
         valid_chars = "-_.() " + string.ascii_letters + string.digits
-        cleaned_title = unicodedata.normalize("NFKD", self.full_title)
+        cleaned_title = unicodedata.normalize("NFKD", self.full_title or "")
         cleaned_title = cleaned_title.encode("ASCII", "ignore")
         cleaned_title = cleaned_title.replace(b" ", b"_")
         slug_title = "".join(
@@ -84,7 +84,7 @@ class BaseItem:
             base_filename = self.full_title_slugify
 
         elif "unicode" in mode:
-            base_filename = unicodedata.normalize("NFKD", self.full_title)
+            base_filename = unicodedata.normalize("NFKD", self.full_title or "")
 
         else:
             base_filename = self.asin
@@ -272,36 +272,49 @@ class LibraryItem(BaseItem):
         }
         return httpx.URL(url, params=params), codec_name
 
-    async def get_aaxc_url(self, quality: str = "high"):
+    async def get_aaxc_url(
+            self,
+            quality: str = "high",
+            license_response_groups: Optional[str] = None
+    ):
         if not self.is_downloadable():
             raise AudibleCliException(
                 f"{self.full_title} is not downloadable."
             )
 
+        lr = await self.get_license(quality, license_response_groups)
+
+        content_metadata = lr["content_license"]["content_metadata"]
+        url = httpx.URL(content_metadata["content_url"]["offline_url"])
+        codec = content_metadata["content_reference"]["content_format"]
+
+        return url, codec, lr
+
+    async def get_license(
+            self,
+            quality: str = "high",
+            response_groups: Optional[str] = None
+    ):
         assert quality in ("best", "high", "normal",)
 
+        if response_groups is None:
+            response_groups = "last_position_heard, pdf_url, content_reference"
+
         body = {
             "supported_drm_types": ["Mpeg", "Adrm"],
-            "quality": "Extreme" if quality in ("best", "high") else "Normal",
+            "quality": "High" if quality in ("best", "high") else "Normal",
             "consumption_type": "Download",
-            "response_groups": (
-                "last_position_heard, pdf_url, content_reference, chapter_info"
-            )
+            "response_groups": response_groups
         }
 
         lr = await self._client.post(
             f"content/{self.asin}/licenserequest",
             body=body
         )
-
-        content_metadata = lr["content_license"]["content_metadata"]
-        url = httpx.URL(content_metadata["content_url"]["offline_url"])
-        codec = content_metadata["content_reference"]["content_format"]
-
         voucher = decrypt_voucher_from_licenserequest(self._client.auth, lr)
         lr["content_license"]["license_response"] = voucher
 
-        return url, codec, lr
+        return lr
 
     async def get_content_metadata(self, quality: str = "high"):
         assert quality in ("best", "high", "normal",)
@@ -310,7 +323,7 @@ class LibraryItem(BaseItem):
         params = {
             "response_groups": "last_position_heard, content_reference, "
                                "chapter_info",
-            "quality": "Extreme" if quality in ("best", "high") else "Normal",
+            "quality": "High" if quality in ("best", "high") else "Normal",
             "drm_type": "Adrm"
         }
 
@@ -437,8 +450,8 @@ class Library(BaseList):
         library, total_count = await cls.from_api(
             api_client,
             page=1,
-            params=request_params,
             include_total_count_header=True,
+            **request_params
         )
         pages = ceil(int(total_count) / bunch_size)
         if pages == 1:
@@ -450,7 +463,7 @@ class Library(BaseList):
                 cls.from_api(
                     api_client,
                     page=page,
-                    params=request_params,
+                    **request_params
                 )
             )
 
